@@ -85,7 +85,7 @@ use Exporter;
 
 use vars qw ( $AUTOLOAD $LAST_ERROR );
 
-$Net::Blogger::VERSION   = '0.8.4';
+$Net::Blogger::VERSION   = '0.7';
 @Net::Blogger::ISA       = qw (Exporter);
 @Net::Blogger::EXPORT    = qw ();
 @Net::Blogger::EXPORT_OK = qw ();
@@ -99,7 +99,7 @@ Instantiate a new Blogger object.
 
 Valid arguments are :
 
-=over 4
+=over
 
 =item *
 
@@ -166,7 +166,7 @@ sub init {
 
 =head1 Blogger API METHODS
 
-=head2 $pkg->getUsersBlogs()
+=head2 $pkg->getUserBlogs()
 
 Fetch the I<blogid>, I<url> and I<blogName> for each of the Blogger blogs the current user is registered to.
 
@@ -178,7 +178,7 @@ Add a new post to the Blogger server.
 
 Valid arguments are :
 
-=over 4
+=over
 
 =item *
 
@@ -208,7 +208,7 @@ Fetch the latest (n) number of posts for a given blog. The most recent posts are
 
 Valid arguments are 
 
-=over 4
+=over
 
 =item * 
 
@@ -230,7 +230,7 @@ Update the Blogger database. Set the body of entry $postid to $body.
 
 Valid arguments are :
 
-=over 4
+=over
 
 =item * 
 
@@ -262,7 +262,7 @@ Delete a post from the Blogger server.
 
 Valid arguments are 
 
-=over 4
+=over
 
 =item * 
 
@@ -280,6 +280,57 @@ Boolean.
 
 Returns true or false.
 
+=head2 $pkg->deletePost(%args) 
+
+Delete a post from the Blogger server.
+
+Valid arguments are 
+
+=over
+
+=item * 
+
+B<postid> (required)
+
+String.
+
+=item * 
+
+B<publish> 
+
+Boolean.
+
+=back
+
+Returns true or false.
+
+=cut
+
+sub deletePost {
+    my $self = shift;
+    my $args = { @_ };
+
+    my $postid = $args->{'postid'};
+
+    if (! $postid) {
+	$self->LastError("No post id.");
+	return 0;
+    }
+
+    my $publish = ($args->{'publish'}) ? 1 : 0;
+
+    my $call = $self->_Client->call(
+				    "blogger.deletePost",
+				    $self->_Type(string=>$self->AppKey()),
+				    $self->_Type(string=>$postid),
+				    $self->_Type(string=>$self->Username()),
+				    $self->_Type(string=>$self->Password()),
+				    $self->_Type(boolean=>$publish),
+				    );
+
+    ($call) ? return $call->result() : return 0;
+}
+
 =head2 $pkg->setTemplate(%args)
 
 Set the body of the template matching type I<$type>.
@@ -288,7 +339,7 @@ Set the body of the template matching type I<$type>.
 
 Valid arguments are 
 
-=over 4
+=over
 
 =item * 
 
@@ -312,7 +363,7 @@ Fetch the body of the template matching type I<$type>.
 
 Valid types are 
 
-=over 4
+=over
 
 =item * 
 
@@ -336,7 +387,7 @@ Return the unique blogid for I<$args{'blogname'}>.
 
 Valid arguments are 
 
-=over 4
+=over
 
 =item * 
 
@@ -358,7 +409,7 @@ Open a filehandle, and while true, post to Blogger. If the length of the amount
 
 Valid arguments are 
 
-=over 4 
+=over 
 
 =item *
 
@@ -402,7 +453,7 @@ Valid outline formats are OPML, tabbed text outline, Emacs' outline-mode format,
 
 Valid arguments are 
 
-=over 4 
+=over 
 
 =item * 
 
@@ -442,11 +493,11 @@ sub AUTOLOAD {
 
 =head1 VERSION
 
-0.8.4
+0.7
 
 =head1 DATE
 
-January 10, 2003
+May 04, 2002
 
 =head1 AUTHOR
 
@@ -462,65 +513,9 @@ http://plant.blogger.com/api/
 
 =head1 CHANGES
 
-=head2 0.8,4
-
-=over 4
-
-=item *
-
-Added support for the I<metaWeblog.newMediaObject> method.
-
-=item *
-
-Updated POD
-
-=back
-
-=head2 0.8.3
-
-=over 4
-
-=item *
-
-Updated POD
-
-=back
-
-=head2 0.8.2
-
-=over 4
-
-=item *
-
-Added support for the metaWeblog API to the Manila engine.
-
-=back
-
-=head2 0.8.1
-
-=over 4
-
-=item *
-
-Added support for the mt.getTrackbackPings method in I<Net::Blogger::Engine::Movabletype::mt.pm>
-
-=back
-
-=head2 0.8
-
-=over 4
-
-=item *
-
-Added I<Slash> engine
-
-=back
-
-=head2 0.7
-
 =head2 0.6.4
 
-=over 4
+=over
 
 =item *
 
@@ -534,7 +529,7 @@ Added quotes to all the VERSION numbers
 
 =head2 0.6.3
 
-=over 4
+=over
 
 =item *
 
@@ -544,7 +539,7 @@ Updated POD for I<Net::Blogger> and all child packages.
 
 =head2 0.6.2.2
 
-=over 4
+=over
 
 =item *
 
@@ -554,7 +549,7 @@ No changes. But, since I uploaded the current codebase to the CPAN as v 0.6.1.2,
 
 =head2 0.6.2.1
 
-=over 4
+=over
 
 =item * 
 
@@ -564,7 +559,7 @@ Updated POD.
 
 =head2 0.6.2
 
-=over 4
+=over
 
 =item * 
 
@@ -574,7 +569,7 @@ Added support for the UserLand metaWeblog API in the I<RadioUserLand> engine
 
 =head2 0.6.1
 
-=over 4
+=over
 
 =item *
 
@@ -584,7 +579,7 @@ Bugs fixes in I<Net::Blogger::Engine::Base>
 
 =head2 0.6
 
-=over 4
+=over
 
 =item *
 
@@ -602,7 +597,7 @@ Updated POD
 
 =head2 0.5.1
 
-=over 4
+=over
 
 =item *
 
@@ -616,7 +611,7 @@ Updated POD.
 
 =head2 0.5
 
-=over 4
+=over
 
 =item * 
 
@@ -630,7 +625,7 @@ Updated POD.
 
 =head2 0.4.6.1
 
-=over 4
+=over
 
 =item *
 
@@ -640,7 +635,7 @@ Added conditional, where necessary, to see if a maximum post length is applicabl
 
 =head2 0.4.6
 
-=over 4
+=over
 
 =item *
 
@@ -658,7 +653,7 @@ Updated POD
 
 =head2 0.4.5
 
-=over 4
+=over
 
 =item * 
 
@@ -672,7 +667,7 @@ Updated POD
 
 =head2 0.4.4.1
 
-=over 4
+=over
 
 =item *
 
@@ -686,7 +681,7 @@ Fixed remaining instances of "Error::Simple->record() and return 0" in &AUTOLOAD
 
 =head2 0.4.4
 
-=over 4
+=over
 
 =item * 
 
@@ -716,7 +711,7 @@ Updated POD.
 
 =head2 0.4.3
 
-=over 4
+=over
 
 =item * 
 
@@ -726,7 +721,7 @@ Made sure all Blogger.pm methods begin with title case.
 
 =head2 0.4.2
 
-=over 4
+=over
 
 =item * 
 
@@ -744,7 +739,7 @@ Fixed a bug in Blogger.pm I<_PostInChunks> method where I would end up subscript
 
 =head2 0.4.1
 
-=over 4
+=over
 
 =item *
 
@@ -754,7 +749,7 @@ Added idiot-level escaping of entities in Blogger.pm I<newPost> and I<editPost>
 
 =head2 0.4
 
-=over 4
+=over
 
 =item *
 
@@ -780,7 +775,7 @@ Updated POD
 
 =head2 0.3.1
 
-=over 4
+=over
 
 =item *
 
@@ -790,7 +785,7 @@ Updated POD
 
 =head2 0.3
 
-=over 4
+=over
 
 =item *
 
@@ -812,7 +807,7 @@ Changed the return value of both the Blogger API I<newPost> and I<editPost> meth
 
 =head2 0.2
 
-=over 4
+=over
 
 =item * 
 
@@ -835,7 +830,7 @@ Modifed the Blogger API I<newPost> method to accept the option to publish.
 
 =head2 0.1
 
-=over 4
+=over
 
 =item *
 
@@ -853,17 +848,12 @@ Added the Blogger API I<newPost> method.
 
 Added the Blogger.pm I<Publish> method.
 
+
 =back
 
-=head1 BUGS
-
-Hopefully, few.
-
-Please reports all bugs to http://rt.cpan.org/NoAuth/ReportBug.html?Queue=Net::Blogger
-
 =head1 LICENSE
 
-Copyright (c) 2001-2003 Aaron Straup Cope.
+Copyright (c) 2001-2002 Aaron Straup Cope.
 
 This is free software, you may use it and distribute it under the same terms as Perl itself.
 
