@@ -37,7 +37,7 @@ use strict;
 
 use vars qw ( $AUTOLOAD );
 
-$Net::Blogger::Engine::Base::VERSION        = '0.3.1';
+$Net::Blogger::Engine::Base::VERSION        = '0.2';
 @Net::Blogger::Engine::Base::ISA            = qw ( Exporter Net::Blogger::API::Core Net::Blogger::API::Extended );
 @Net::Blogger::Engine::Base::ISA::EXPORT    = qw ();
 @Net::Blogger::Engine::Base::ISA::EXPORT_OK = qw ();
@@ -46,7 +46,7 @@ use Carp;
 use Error;
 use Exporter;
 
-use SOAP::Lite;
+use XMLRPC::Lite;
 
 use Net::Blogger::API::Core;
 use Net::Blogger::API::Extended;
@@ -59,7 +59,7 @@ Instantiate a new Blogger object.
 
 Valid arguments are :
 
-=over 4
+=over
 
 =item *
 
@@ -179,58 +179,34 @@ sub LastError {
     return $e;
 }
 
-sub Transport {
-  return "XMLRPC";
-}
-
 =head1 PRIVATE METHODS
 
 =cut
 
 =head2 $pkg->_Client()
 
-Return an XML-RPC or SOAP client object.
+Return an XML-RPC client object.
 
 =cut
 
 sub _Client {
     my $self = shift;
 
-    unless (ref($self->{"_client"}) =~ /^(XMLRPC|SOAP)::Lite$/) {
-
-      my $pkg = uc $self->Transport();
-
-      if ($pkg =~ /^(XMLRPC|SOAP)$/) {
-	$pkg = join("::",$pkg,"Lite");
-      } 
-
-      else {
-	die "Unknown transport : '$pkg'\n";
-	$self->LastError("Unknown transport : $pkg");
-	return undef;
-      }
-
-      eval "require $pkg";
-
-      if ($@) {
-	die "Failed to eval, $@\n";
-      }
-      my $client = $pkg->new()
+    if (ref($self->{"_xmlrpc"}) ne "XMLRPC::Lite") {
+      my $client = XMLRPC::Lite->new()
 	|| Error->throw(-text=>$!);
 
       $client->on_fault(\&_ClientFault);
       $client->proxy($self->Proxy); 
-      $client->uri($self->Uri());
 
-      # Fix this.
       if ($self->{'debug'}) {
 	$client->on_debug(sub { print @_; });
       }
 
-      $self->{"_client"} = $client;
+      $self->{"_xmlrpc"} = $client;
     }
 
-    return $self->{"_client"};
+    return $self->{"_xmlrpc"};
 }
 
 sub _ClientFault {
@@ -252,10 +228,10 @@ sub _Type {
   my $name = shift;
 
   if ($name =~ /^(hash|array)$/) {
-    return SOAP::Data->name(args=>@_);
+    return XMLRPC::Data->name(args=>@_);
   }
 
-  return SOAP::Data->type($name,@_);
+  return XMLRPC::Data->type($name,@_);
 }
 
 sub DESTROY {
@@ -271,7 +247,7 @@ sub AUTOLOAD {
 	return undef;
     }
 
-    unless ($AUTOLOAD =~ /^(Proxy|Uri|AppKey|BlogId|Username|Password)$/) {
+    unless ($AUTOLOAD =~ /^(Proxy|AppKey|BlogId|Username|Password)$/) {
 	$self->LastError("Unkown method '$AUTOLOAD' called. Skipping.");
 	return undef;
     }
@@ -279,38 +255,32 @@ sub AUTOLOAD {
     my $property = lc "_".$AUTOLOAD;
 
     if (my $arg = shift) { 
-      $self->{ $property } = $arg; 
-     
-      if ($AUTOLOAD eq "Proxy") {
-	$self->{"_client"} = undef;
-      }
-      
-      #
+	$self->{ $property } = $arg; 
 
-      if (exists $self->{'__meta'}) {
-	$self->{'__meta'}->$property($arg);
-      }
-      
-      if (exists $self->{'__mt'}) {
-	$self->{'__mt'}->$property($arg);
-      }
-      
-      if (exists $self->{'__slash'}) {
-	$self->{'__slash'}->$property($arg);
-      }
+	if (exists $self->{'__meta'}) {
+	  $self->{'__meta'}->$property($arg);
+	}
+
+	if (exists $self->{'__mt'}) {
+	  $self->{'__mt'}->$property($arg);
+	}
 
     }
    
+    if ($AUTOLOAD eq "Proxy") {
+	$self->{"_xmlrpc"} = undef;
+    }
+
     return $self->{ $property };
 }
 
 =head1 VERSION
 
-0.3.1
+0.2
 
 =head1 DATE
 
-September 02, 2002
+May 04, 2002
 
 =head1 AUTHOR
 
@@ -326,37 +296,9 @@ L<SOAP::Lite>
 
 =head1 CHANGES
 
-=head2 0.3.1
-
-=over 4
-
-=item *
-
-Fixed to undef _client only if arg is passed to I<Proxy>
-
-=item * 
-
-Updated POD.
-
-=back
-
-=head2 0.3
-
-=over 4
-
-=item * 
-
-Switched to SOAP::Lite rather than XMLRPC::Lite
-
-=item *
-
-Added I<Transport> and I<Uri>
-
-=back
-
 =head2 0.2
 
-=over 4
+=over
 
 =item *
 
@@ -374,7 +316,7 @@ Added quotes to I<$VERSION>
 
 =head2 0.1.3
 
-=over 4
+=over
 
 =item *
 
@@ -384,7 +326,7 @@ Updated POD
 
 =head2 0.1.2
 
-=over 4
+=over
 
 =item * 
 
@@ -394,7 +336,7 @@ Updated POD
 
 =head2 0.1.1
 
-=over 4
+=over
 
 =item *
 
@@ -408,7 +350,7 @@ No need to pass I<$self> to I<&_ClientFault>.
 
 =head2 0.1
 
-=over 4
+=over
 
 =item *
 
