@@ -19,7 +19,7 @@ This package should not be called directly. It is a base class used by I<Net::Bl
 package Net::Blogger::Engine::Userland;
 use strict;
 
-$Net::Blogger::Engine::Userland::VERSION   = '0.3.1';
+$Net::Blogger::Engine::Userland::VERSION   = '0.2.3';
 @Net::Blogger::Engine::Userland::ISA       = qw ( Exporter Net::Blogger::Engine::Base );
 @Net::Blogger::Engine::Userland::EXPORT    = qw ();
 @Net::Blogger::Engine::Userland::EXPORT_OK = qw ();
@@ -87,8 +87,6 @@ sub Proxy {
     if (my $blog = $self->BlogId()) {
 	my $uri = URI->new($blog);
 	$self->{"_proxy"} = $uri->scheme()."://".$uri->host()."/RPC2";
-
-	$self->{"_client"} = undef;
 	return $self->{"_proxy"};
     }
 
@@ -107,26 +105,6 @@ sub AppKey {
     return 1;
 }
 
-=head2 $pkg->BlogId()
-
-Get/Set the current blog id.
-
-Ensures that the blogid contains a trailing slash, without which the Frontier engine freaks out.
-
-=cut
-
-sub BlogId {
-  my $self = shift;
-  my $id   = shift;
-
-  if ($id) {
-    unless ($id =~ /^(.*)\/$/) { $id .= "/"; }
-    $self->{'_blogid'} = $id;
-  }
-
-  return $self->{'_blogid'};
-}
-
 =head2 $pkg->MaxPostLength()
 
 By default, returns undef. In other words, there is no max post length for Manila.
@@ -140,37 +118,15 @@ sub MaxPostLength {
     return undef;
 }
 
-
-=head1 metaWeblog API METHODS
-
-=head2 $pkg->metaWeblog()
-
-=cut
-
-sub metaWeblog {
-  my $self = shift;
-
-  if (! $self->{__meta}) {
-
-    require Net::Blogger::Engine::Userland::metaWeblog;
-    my $meta = Net::Blogger::Engine::Userland::metaWeblog->new(debug=>$self->{debug});
-
-    map { $meta->$_($self->$_()); } qw (BlogId Proxy Username Password );
-    $self->{__meta} = $meta;
-  }
-
-  return $self->{__meta};
-}
-
 return 1;
 
 =head1 VERSION
 
-0.3.1
+0.2.3
 
 =head1 DATE
 
-September 02, 2002
+May 04, 2002
 
 =head1 AUTHOR
 
@@ -178,33 +134,9 @@ Aaron Straup Cope
 
 =head1 CHANGES
 
-=head2 0.3.1
-
-=over 4
-
-=item *
-
-Reset _client when I<Proxy> is called with a new value.
-
-=item *
-
-Updated POD
-
-=back
-
-=head2 0.3
-
-=over 4 
-
-=item *
-
-Added $pkg->metaWeblog()
-
-back
-
 =head2 0.2.3
 
-=over 4
+=over
 
 =item *
 
@@ -214,7 +146,7 @@ Added quotes to I<$VERSION>
 
 =head2 0.2.2
 
-=over 4
+=over
 
 =item *
 
@@ -224,7 +156,7 @@ Updated POD
 
 =head2 0.2.1
 
-=over 4
+=over
 
 =item * 
 
@@ -234,7 +166,7 @@ Updated POD
 
 =head2 0.2
 
-=over 4
+=over
 
 =item *
 
@@ -248,7 +180,7 @@ Update POD.
 
 =head2 0.1.1
 
-=over 4
+=over
 
 =item *
 
@@ -270,7 +202,7 @@ Updated POD.
 
 =head2 0.1
 
-=over 4
+=over
 
 =item
 
